@@ -1,6 +1,7 @@
 from typing import Mapping, NotRequired
 from pydantic import ConfigDict, TypeAdapter, ValidationError
 from ..modeling.basics import Attrs
+from ..modeling.resource_type_helpers import ResourceTypeDescriptor
 
 
 def validate_typed_dict(data: dict | Mapping, typed_dict_class: type) -> None:
@@ -24,6 +25,11 @@ ta_NoExtrasAttrs = TypeAdapter(NoExtrasAttrs)
 
 
 def validate_pvradar_attrs(data: Mapping) -> None:
+    if isinstance(data, (type(ResourceTypeDescriptor), ResourceTypeDescriptor)):
+        # validation is skipped, because it was already performed in the corresponding constructor
+        return
+    if len(data.keys()) == 0:
+        return
     try:
         ta_NoExtrasAttrs.validate_python(data)
     except ValidationError as e:
