@@ -30,7 +30,7 @@ class DataCaseTable(DataCase):
 
 
 class DataCaseScalar(DataCase):
-    data: Union[int, float, str, None]
+    data: Union[int, float, str, dict, None]
     meta: NotRequired[Mapping[str, Any]]
 
 
