@@ -1,10 +1,22 @@
 from .model_context import ModelWrapper, ModelContext
-from .decorators import resource_type, label, name, to_unit, set_unit, audience, pvradar_resource_type
-from .basics import attrs, Attrs, ModelParamAttrs, PvradarResourceType, is_pvradar_resource_type, Datasource, ModelConfig
+from .decorators import resource_type, label, to_unit, set_unit, audience, pvradar_resource_type
+from .basics import (
+    attrs,
+    Attrs,
+    ModelParamAttrs,
+    PvradarResourceType,
+    is_pvradar_resource_type,
+    Datasource,
+    ModelConfig,
+    LambdaArgument,
+)
 from .geo_located_model_context import GeoLocatedModelContext
 from .library_manager import load_libraries
-from .utils import resample_series, convert_series_unit, ureg
+from .utils import resample_series, convert_series_unit, ureg, convert_to_resource
 from .base_model_context import BaseModelContext
+from .profiling.profiler import PvradarProfiler
+from .hooks import for_argument, for_resource
+from . import resource_types as R
 
 __all__ = [
     # ------------------------------
@@ -13,6 +25,7 @@ __all__ = [
     'attrs',
     'Attrs',
     'Datasource',
+    'LambdaArgument',
     'ModelConfig',
     'ModelParamAttrs',
     'PvradarResourceType',
@@ -28,7 +41,6 @@ __all__ = [
     #
     'set_unit',
     'to_unit',
-    'name',
     'label',
     'resource_type',
     'pvradar_resource_type',
@@ -38,10 +50,18 @@ __all__ = [
     #
     'resample_series',
     'convert_series_unit',
+    'convert_to_resource',
     'ureg',
     # ------------------------------
+    # Hooks
+    #
+    'for_argument',
+    'for_resource',
+    # ------------------------------
     # Other
     #
+    'PvradarProfiler',
     'load_libraries',
     'BaseModelContext',
+    'R',
 ]
