@@ -1,6 +1,6 @@
 from typing import TypedDict
 
-from pvradar.sdk.modeling.basics import ModelRecipe
+from ..basics import ModelRecipe
 
 
 class SweepRange(TypedDict):
